==> capsaicin-1.18-1.2.1%2Bmc1.18.2-sources.jar: de/siphalor/capsaicin/impl/mixin/MixinCakeBlock.java <==
package de.siphalor.capsaicin.impl.mixin;

import com.mojang.datafixers.util.Pair;
import de.siphalor.capsaicin.api.food.FoodEvents;
import de.siphalor.capsaicin.impl.food.FoodHandler;
import de.siphalor.capsaicin.impl.food.event.EatenEvent;
import de.siphalor.capsaicin.impl.food.properties.FoodPropertiesImpl;
import org.jetbrains.annotations.ApiStatus;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.ArrayList;
import java.util.Random;
import net.minecraft.class_1269;
import net.minecraft.class_1293;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1702;
import net.minecraft.class_1936;
import net.minecraft.class_2272;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_4174;

@ApiStatus.Internal
@Mixin(class_2272.class)
public class MixinCakeBlock {
	@Inject(method = "tryEat", at = @At("HEAD"))
	private static void onEat(class_1936 world, class_2338 pos, class_2680 state, class_1657 player, CallbackInfoReturnable<class_1269> cir) {
		FoodHandler foodHandler = FoodHandler.INSTANCE.get();
		foodHandler.reset();
		foodHandler.withUser(player);
		foodHandler.withBlockState(state, new FoodPropertiesImpl(2, 0.1F, false, new ArrayList<>()));
	}

	@Redirect(method = "tryEat", at = @At(value = "INVOKE", target = "Lnet/minecraft/entity/player/HungerManager;add(IF)V"))
	private static void eat(class_1702 hungerManager, int hunger, float saturationModifier) {
		FoodHandler foodHandler = FoodHandler.INSTANCE.get();
		class_4174 foodProperties = foodHandler.getFoodComponent();

		class_1309 user = foodHandler.getUser();
		Random random = user.method_6051();
		hungerManager.method_7585(foodProperties.method_19230(), foodProperties.method_19231());
		for (Pair<class_1293, Float> effect : foodProperties.method_19235()) {
			if (random.nextFloat() < effect.getSecond()) {
				user.method_6092(effect.getFirst());
			}
		}
		FoodEvents.EATEN.emit(new EatenEvent(foodHandler.createContext()));

		foodHandler.reset();
	}
}

==> capsaicin-1.18-1.3.1%2Bmc1.18.2-sources.jar: de/siphalor/capsaicin/impl/mixin/MixinCakeBlock.java <==
package de.siphalor.capsaicin.impl.mixin;

import com.mojang.datafixers.util.Pair;
import de.siphalor.capsaicin.api.food.FoodEvents;
import de.siphalor.capsaicin.impl.food.FoodHandler;
import de.siphalor.capsaicin.impl.food.event.EatenEvent;
import de.siphalor.capsaicin.impl.food.properties.FoodPropertiesImpl;
import org.jetbrains.annotations.ApiStatus;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.ArrayList;
import java.util.Random;
import net.minecraft.class_1269;
import net.minecraft.class_1293;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1702;
import net.minecraft.class_1936;
import net.minecraft.class_2272;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_4174;

@ApiStatus.Internal
@Mixin(class_2272.class)
public class MixinCakeBlock {
	@Inject(method = "tryEat", at = @At("HEAD"))
	private static void onEat(class_1936 world, class_2338 pos, class_2680 state, class_1657 player, CallbackInfoReturnable<class_1269> cir) {
		FoodHandler foodHandler = FoodHandler.INSTANCE.get();
		foodHandler.reset();
		foodHandler.withUser(player);
		foodHandler.withBlockState(state, new FoodPropertiesImpl(2, 0.1F, false, new ArrayList<>()));
	}

	@Redirect(method = "tryEat", at = @At(value = "INVOKE", target = "Lnet/minecraft/entity/player/HungerManager;add(IF)V"))
	private static void eat(class_1702 hungerManager, int hunger, float saturationModifier) {
		FoodHandler foodHandler = FoodHandler.INSTANCE.get();
		class_4174 foodComponent = foodHandler.getModifiedFoodComponent();

		if (foodComponent != null) {
			class_1309 user = foodHandler.getUser();
			Random random = user.method_6051();
			hungerManager.method_7585(foodComponent.method_19230(), foodComponent.method_19231());
			for (Pair<class_1293, Float> effect : foodComponent.method_19235()) {
				if (random.nextFloat() < effect.getSecond()) {
					user.method_6092(effect.getFirst());
				}
			}
			FoodEvents.EATEN.emit(new EatenEvent(foodHandler.createContext()));
		}

		foodHandler.reset();
	}
}
